from django.db import models
from django.contrib.auth.models import User, UserManager
from django.utils.translation import ugettext, ugettext_lazy as _
from publishing.models import Publication

# Create your models here.

class UserProfile(models.Model):

	TYPES = (
		('undergraduated', _('Undegraduated Student')),
		('msc', _('MSc Student')),
		('phd', _('PhD Student')),
		('professor', _('Professor')),
		('researcher', _('Researcher')),
	)
	
	bibliographical_name = models.CharField(max_length = 30, help_text = _('This name will be used in your publication\'s bibliography.'))
	user = models.ForeignKey(User, unique=True, related_name='profile')
	kind = models.CharField(max_length=30, choices=TYPES)
	departament = models.CharField(max_length=30)
	phone_number = models.CharField(max_length=30)
	city = models.CharField(max_length=100)
	country = models.CharField(max_length=100)
	site = models.URLField(blank=True)
	photo = models.ImageField(upload_to='uploads', null=True, blank=True)
	active = models.BooleanField()
	advisor = models.CharField(max_length=30, null=True, blank=True)
	co_advisor = models.CharField(max_length=30, null=True, blank=True)	
	
	def __unicode__(self):
		return "%s, %s" % (self.user.last_name, self.user.first_name)
		
	@staticmethod
	def get_group_publication_set(users):
		qs = Publication.objects
		for user in users:
			qs = qs.filter(member_authors=user)
		
		return qs
		
"""
class Authoring(models.Model):
	member_author = models.ManyToManyField(User, related_name='authoring_set')
	publication 	= models.ForeignKey(Publication, unique = True, related_name='authoring')
	other_authors = models.TextField(help_text = _('Separate the authors using "and". Do not use commas.'), blank=True, null=True)
"""	
	

